@@ -1,9 +1,8 @@
-use crate::ops::{Begin, BeginMut, End, EndMut};
 use crate::{CppBox, CppDeletable, DynamicCast, MutRef, Ref, StaticDowncast, StaticUpcast};
 use std::ffi::CStr;
+use std::fmt;
 use std::ops::{Deref, DerefMut};
 use std::os::raw::c_char;
-use std::{fmt, mem, slice};
 
 /// A mutable pointer to a C++ object (similar to a C++ pointer).
 ///
@@ -199,121 +198,6 @@ impl<T> MutPtr<T> {
     {
         DynamicCast::dynamic_cast_mut(self)
     }
-
-    /// Returns a C++ const iterator object pointing to the beginning of the collection.
-    ///
-    /// It's recommended to iterate directly on a `MutPtr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn begin(self) -> <&'static T as Begin>::Output
-    where
-        &'static T: Begin,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null MutPtr<T>");
-        }
-        (*self.as_raw_ptr()).begin()
-    }
-
-    /// Returns a C++ mutable iterator object pointing to the beginning of the collection.
-    ///
-    /// It's recommended to iterate directly on a `MutPtr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn begin_mut(self) -> <&'static mut T as BeginMut>::Output
-    where
-        &'static mut T: BeginMut,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null MutPtr<T>");
-        }
-        (*self.as_mut_raw_ptr()).begin_mut()
-    }
-
-    /// Returns a C++ const iterator object pointing to the end of the collection.
-    ///
-    /// It's recommended to iterate directly on a `MutPtr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn end(self) -> <&'static T as End>::Output
-    where
-        &'static T: End,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null MutPtr<T>");
-        }
-        (*self.as_raw_ptr()).end()
-    }
-
-    /// Returns a C++ mutable iterator object pointing to the end of the collection.
-    ///
-    /// It's recommended to iterate directly on a `MutPtr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn end_mut(self) -> <&'static mut T as EndMut>::Output
-    where
-        &'static mut T: EndMut,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null MutPtr<T>");
-        }
-        (*self.as_mut_raw_ptr()).end_mut()
-    }
-
-    /// Returns a slice corresponding to the object. This function is available when `begin()` and
-    /// `end()` functions of the object return pointers.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code. It's not recommended to store the slice
-    /// because it may be modified by the C++ library, which would violate Rust's aliasing rules.
-    pub unsafe fn as_slice<'a, T1>(self) -> &'a [T1]
-    where
-        T: 'static,
-        &'static T: Begin<Output = Ptr<T1>> + End<Output = Ptr<T1>>,
-    {
-        let begin = self.begin().as_raw_ptr();
-        let end = self.end().as_raw_ptr();
-        let count = (end as usize).saturating_sub(begin as usize) / mem::size_of::<T1>();
-        slice::from_raw_parts(begin, count)
-    }
-
-    /// Returns a mutable slice corresponding to the object.
-    /// This function is available when `begin()` and
-    /// `end()` functions of the object return pointers.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code. It's not recommended to store the slice
-    /// because it may be modified by the C++ library, which would violate Rust's aliasing rules.
-    pub unsafe fn as_mut_slice<'a, T1>(self) -> &'a mut [T1]
-    where
-        T: 'static,
-        &'static mut T: BeginMut<Output = MutPtr<T1>> + EndMut<Output = MutPtr<T1>>,
-    {
-        let begin = self.begin_mut().as_mut_raw_ptr();
-        let end = self.end_mut().as_mut_raw_ptr();
-        let count = (end as usize).saturating_sub(begin as usize) / mem::size_of::<T1>();
-        slice::from_raw_parts_mut(begin, count)
-    }
 }
 
 impl<T: CppDeletable> MutPtr<T> {
@@ -507,63 +391,6 @@ impl<T> Ptr<T> {
     {
         DynamicCast::dynamic_cast(self)
     }
-
-    /// Returns a C++ const iterator object pointing to the beginning of the collection.
-    ///
-    /// It's recommended to iterate directly on a `Ptr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn begin(self) -> <&'static T as Begin>::Output
-    where
-        &'static T: Begin,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null Ptr<T>");
-        }
-        (*self.as_raw_ptr()).begin()
-    }
-
-    /// Returns a C++ const iterator object pointing to the end of the collection.
-    ///
-    /// It's recommended to iterate directly on a `Ptr<T>` when possible, using automatic
-    /// `IntoIterator` implementation.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code.
-    pub unsafe fn end(self) -> <&'static T as End>::Output
-    where
-        &'static T: End,
-    {
-        if self.0.is_null() {
-            panic!("attempted to deref a null Ptr<T>");
-        }
-        (*self.as_raw_ptr()).end()
-    }
-
-    /// Returns a slice corresponding to the object. This function is available when `begin()` and
-    /// `end()` functions of the object return pointers.
-    ///
-    /// ### Safety
-    ///
-    /// `self` must be valid. It's not possible to make any guarantees about safety, since
-    /// this function calls arbitrary C++ library code. It's not recommended to store the slice
-    /// because it may be modified by the C++ library, which would violate Rust's aliasing rules.
-    pub unsafe fn as_slice<'a, T1>(self) -> &'a [T1]
-    where
-        T: 'static,
-        &'static T: Begin<Output = Ptr<T1>> + End<Output = Ptr<T1>>,
-    {
-        let begin = self.begin().as_raw_ptr();
-        let end = self.end().as_raw_ptr();
-        let count = (end as usize).saturating_sub(begin as usize) / mem::size_of::<T1>();
-        slice::from_raw_parts(begin, count)
-    }
 }
 
 /// Allows to call member functions of `T` and its base classes directly on the pointer.
